@@ -29,13 +29,16 @@ AdamType<UpdateRule>::AdamType(
     const double epsilon,
     const size_t maxIterations,
     const double tolerance,
-    const bool shuffle) :
+    const bool shuffle,
+    const bool resetPolicy) :
     optimizer(stepSize,
               batchSize,
               maxIterations,
               tolerance,
               shuffle,
-              UpdateRule(epsilon, beta1, beta2))
+              UpdateRule(epsilon, beta1, beta2),
+              NoDecay(),
+              resetPolicy)
 { /* Nothing to do. */ }
 
 } // namespace ens
