@@ -51,25 +51,9 @@ namespace ens {
  * point.  Then, SGD considers the gradient of the objective function operating
  * on an individual point in its update of \f$ A \f$.
  *
- * For SGD to work, a DecomposableFunctionType template parameter is required.
- * This class must implement the following function:
- *
- *   size_t NumFunctions();
- *   double Evaluate(const arma::mat& coordinates,
- *                   const size_t i,
- *                   const size_t batchSize);
- *   void Gradient(const arma::mat& coordinates,
- *                 const size_t i,
- *                 arma::mat& gradient,
- *                 const size_t batchSize);
- *
- * NumFunctions() should return the number of functions (\f$n\f$), and in the
- * other two functions, the parameter i refers to which individual function (or
- * gradient) is being evaluated.  So, for the case of a data-dependent function,
- * such as NCA, NumFunctions() should return the number of points in the
- * dataset, and Evaluate(coordinates, 0) will evaluate the objective function on
- * the first point in the dataset (presumably, the dataset is held internally in
- * the DecomposableFunctionType).
+ * SGD can optimize differentiable separable functions.  For more details, see
+ * the documentation on function types included with this distribution or on the
+ * ensmallen website.
  *
  * @tparam UpdatePolicyType update policy used by SGD during the iterative
  *     update process. By default vanilla update policy (see ens::VanillaUpdate)
@@ -195,6 +179,10 @@ class SGD
   //! Flag indicating whether update policy
   //! should be reset before running optimization.
   bool resetPolicy;
+
+  //! Flag indicating whether the update policy
+  //! parameters have been initialized.
+  bool isInitialized;
 };
 
 using StandardSGD = SGD<VanillaUpdate>;
